<!DOCTYPE TS><TS version="2.1" language="es">
<context>
    <name>ChatRoomWidget</name>
    <message>
        <source>Choose a room to send messages or enter a command...</source>
        <translation>Elija una sala para enviar mensajes o ingrese un comando...</translation>
    </message>
    <message>
        <source>There&apos;s nothing to send</source>
        <translation>No hay nada que enviar</translation>
    </message>
    <message>
        <source>/join argument doesn&apos;t look like a room ID or alias</source>
        <translation>/join argumento no parece un ID de habitación o alias</translation>
    </message>
    <message>
        <source>Sending a farewell message is not supported yet. If you intended to leave another room, switch to it and type /leave there.</source>
        <translation>El envío de un mensaje de despedida aún no es compatible. Si tenía la intención de salir de otra sala, cambie a ella y escriba /leave allí.</translation>
    </message>
    <message>
        <source>/forget must be followed by the room id/alias, even for the current room</source>
        <translation>/forget debe ser seguido por el id/alias de la sala, incluso para la sala actual</translation>
    </message>
    <message>
        <source>%1 doesn&apos;t look like a room id or alias</source>
        <translation>%1 no parece un identificador de sala o alias</translation>
    </message>
    <message>
        <source>/invite &lt;memberId&gt;</source>
        <translation>/invite &lt;memberId&gt;</translation>
    </message>
    <message>
        <source>/%1 &lt;userId&gt; &lt;reason&gt;</source>
        <translation>/%1 &lt;userId&gt; &lt;reason&gt;</translation>
    </message>
    <message>
        <source>%1 is not a member of this room</source>
        <translation>%1 no es miembro de esta sala</translation>
    </message>
    <message>
        <source>/unban &lt;userId&gt;</source>
        <translation>/unban &lt;userId&gt;</translation>
    </message>
    <message>
        <source>/unban argument doesn&apos;t look like a user ID</source>
        <translation>/unban argumento no parece un ID de usuario</translation>
    </message>
    <message>
        <source>/ignore &lt;userId&gt;</source>
        <translation>/ignore &lt;userId&gt;</translation>
    </message>
    <message>
        <source>/ignore argument doesn&apos;t look like a user ID</source>
        <translation>/ignore argumento no parece un ID de usuario</translation>
    </message>
    <message>
        <source>Couldn&apos;t find user %1 on the server</source>
        <translation>No se pudo encontrar el usuario %1 en el servidor</translation>
    </message>
    <message>
        <source>/me needs an argument</source>
        <translation>/me necesita un argumento</translation>
    </message>
    <message>
        <source>/notice needs an argument</source>
        <translation>/notice necesita un argumento</translation>
    </message>
    <message>
        <source>/%1 &lt;memberId&gt; &lt;message&gt;</source>
        <translation>/%1 &lt;memberId&gt; &lt;message&gt;</translation>
    </message>
    <message>
        <source>%1 doesn&apos;t seem to have joined room %2</source>
        <translation>Parece que %1 no se ha unido a la sala %2</translation>
    </message>
    <message>
        <source>%1 doesn&apos;t look like a user id or room alias</source>
        <translation>%1 no parece un ID de usuario o alias de sala</translation>
    </message>
    <message>
        <source>/%1 &lt;memberId&gt;</source>
        <translation>/%1 &lt;memberId&gt;</translation>
    </message>
    <message>
        <source>Unknown /command. Use // to send this line literally</source>
        <translation>/command desconocido. Utilice // para enviar esta línea literalmente</translation>
    </message>
    <message>
        <source>Attach</source>
        <translation>Adjuntar</translation>
    </message>
    <message>
        <source>Attach file</source>
        <translation>Adjuntar archivo</translation>
    </message>
    <message>
        <source>Add a message to the file or just push Enter</source>
        <translation>Agregue un mensaje al archivo o simplemente presione Entrar</translation>
    </message>
    <message>
        <source>Attaching %1</source>
        <translation>Adjuntando %1</translation>
    </message>
    <message>
        <source>Attaching cancelled</source>
        <translation>Adjunto cancelado</translation>
    </message>
    <message>
        <source>There&apos;s no such /command outside of room.</source>
        <translation>No hay tal /comando fuera de la sala.</translation>
    </message>
    <message>
        <source>%1 doesn&apos;t look like a user id</source>
        <translation>%1 no parece un ID de usuario</translation>
    </message>
    <message>
        <source>%1 doesn&apos;t look like a user ID</source>
        <translation>%1 no parece una ID de usuario</translation>
    </message>
    <message>
        <source>You should select a room to send messages.</source>
        <translation>Debe seleccionar una sala para enviar mensajes.</translation>
    </message>
    <message>
        <source>Send a message (over %1) or enter a command...</source>
        <translation>Envía un mensaje (más de %1) o introduce un comando...</translation>
    </message>
    <message>
        <source>Next completion:</source>
        <translation>Próxima finalización:</translation>
    </message>
    <message>
        <source>Currently typing:</source>
        <translation>Actualmente escribiendo:</translation>
    </message>
</context>
<context>
    <name>Timeline</name>
    <message>
        <source>(no topic)</source>
        <translation>(sin tema)</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Desconocido</translation>
    </message>
    <message>
        <source>Unstable room version!</source>
        <translation>¡Versión de sala inestable!</translation>
    </message>
    <message>
        <source>(no name)</source>
        <translation>(sin nombre)</translation>
    </message>
    <message numerus="yes">
        <source>%Ln byte(s)</source>
        <translation>
            <numerusform>%Ln byte</numerusform>
            <numerusform>%Ln bytes</numerusform>
        </translation>
    </message>
    <message>
        <source>%L1 MB</source>
        <translation>%L1 MB</translation>
    </message>
    <message>
        <source>%L1 GB</source>
        <translation>%L1 GB</translation>
    </message>
    <message>
        <source>This room has been upgraded.</source>
        <translation>Esta sala ha sido mejorada.</translation>
    </message>
    <message>
        <source>Room
settings</source>
        <translation>Configuración
de sala</translation>
    </message>
    <message numerus="yes">
        <source>%Ln events back from now</source>
        <translation>
            <numerusform>%Ln evento desde ahora</numerusform>
            <numerusform>%Ln eventos desde ahora</numerusform>
        </translation>
    </message>
    <message>
        <source>%L1 kB</source>
        <translation>%L1 kB</translation>
    </message>
    <message numerus="yes">
        <source>%Ln events cached</source>
        <translation>
            <numerusform>%Ln evento en caché</numerusform>
            <numerusform>%Ln eventos en caché</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>CreateRoomDialog</name>
    <message>
        <source>Create room</source>
        <translation>Crear sala</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Añadir</translation>
    </message>
    <message>
        <source>Invite user(s)</source>
        <translation>Invitar a usuario(s)</translation>
    </message>
    <message>
        <source>Creating the room, please wait</source>
        <translation>Creando la sala, por favor espere</translation>
    </message>
    <message>
        <source>Please fill the fields as desired. None are mandatory</source>
        <translation>Por favor llene los campos como desee. Ninguno es obligatorio</translation>
    </message>
</context>
<context>
    <name>Dialog</name>
    <message>
        <source>Applying changes, please wait</source>
        <translation>Aplicando cambios, por favor espere</translation>
    </message>
</context>
<context>
    <name>LoginDialog</name>
    <message>
        <source>Login</source>
        <translation>Iniciar sesión</translation>
    </message>
    <message>
        <source>Stay logged in</source>
        <translation>Permanecer conectado</translation>
    </message>
    <message>
        <source>Matrix ID</source>
        <translation>ID de Matriz</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Contraseña</translation>
    </message>
    <message>
        <source>Device name</source>
        <translation>Nombre del dispositivo</translation>
    </message>
    <message>
        <source>Connect to server</source>
        <translation>Conectar al servidor</translation>
    </message>
    <message>
        <source>Connecting and logging in, please wait</source>
        <translation>Conectando e iniciando sesión, por favor espere</translation>
    </message>
    <message>
        <source>Re-login</source>
        <translation>Reiniciar sesión</translation>
    </message>
    <message>
        <source>Restoring access, please wait</source>
        <translation>Restaurando el acceso, por favor espere</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Loading...</source>
        <translation>Cargando...</translation>
    </message>
    <message>
        <source>&amp;Accounts</source>
        <translation>&amp;Cuentas</translation>
    </message>
    <message>
        <source>&amp;Login...</source>
        <translation>&amp;Iniciar sesión...</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Salir</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation>&amp;Ver</translation>
    </message>
    <message>
        <source>&amp;Display in timeline</source>
        <translation>&amp;Mostrar en la línea de tiempo</translation>
    </message>
    <message>
        <source>Normal &amp;join/leave events</source>
        <translation>Eventos normales de unión/salida</translation>
    </message>
    <message>
        <source>&amp;Redacted events</source>
        <translation>&amp;Eventos redactados</translation>
    </message>
    <message>
        <source>Show redacted events in the timeline as &apos;Redacted&apos; instead of hiding them entirely</source>
        <translation>Mostrar eventos redactados en la línea de tiempo como &apos;Redactado&apos; en lugar de ocultarlos por completo</translation>
    </message>
    <message>
        <source>&amp;No-effect activity</source>
        <translation>&amp;Actividad sin efectos</translation>
    </message>
    <message>
        <source>Edit tags order</source>
        <translation>Editar orden de etiquetas</translation>
    </message>
    <message>
        <source>&amp;Room</source>
        <translation>&amp;Sala</translation>
    </message>
    <message>
        <source>Change room &amp;settings...</source>
        <translation>Cambiar configuración de sala...</translation>
    </message>
    <message>
        <source>Create &amp;new room...</source>
        <translation>Crear &amp;nueva sala ...</translation>
    </message>
    <message>
        <source>&amp;Join room...</source>
        <translation>&amp;Unirse a la sala...</translation>
    </message>
    <message>
        <source>&amp;Close current room</source>
        <translation>&amp;Cerrar la sala actual</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Configuraciones</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Ayuda</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Acerca de</translation>
    </message>
    <message>
        <source>&amp;Highlight only</source>
        <translation>&amp;Resaltar solamente</translation>
    </message>
    <message>
        <source>Notifications are entirely suppressed</source>
        <translation>Las notificaciones se suprimen por completo.</translation>
    </message>
    <message>
        <source>&amp;Non-intrusive</source>
        <translation>&amp;No intrusivo</translation>
    </message>
    <message>
        <source>Show notifications but do not activate the window</source>
        <translation>Mostrar notificaciones pero no activar la ventana</translation>
    </message>
    <message>
        <source>&amp;Full</source>
        <translation>&amp;Completo</translation>
    </message>
    <message>
        <source>Show notifications and activate the window</source>
        <translation>Mostrar notificaciones y activar la ventana</translation>
    </message>
    <message>
        <source>Notifications</source>
        <translation>Notificaciones</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Predeterminado</translation>
    </message>
    <message>
        <source>The layout with author labels above blocks of messages</source>
        <translation>El diseño con etiquetas de autor sobre bloques de mensajes</translation>
    </message>
    <message>
        <source>The layout with author labels to the left from each message</source>
        <translation>El diseño con etiquetas de autor a la izquierda de cada mensaje</translation>
    </message>
    <message>
        <source>Timeline layout</source>
        <translation>Diseño de la línea de tiempo</translation>
    </message>
    <message>
        <source>Load full-size images at once</source>
        <translation>Cargue imágenes de tamaño completo de una vez</translation>
    </message>
    <message>
        <source>Automatically download a full-size image instead of a thumbnail</source>
        <translation>Descargue automáticamente una imagen a tamaño completo en lugar de una miniatura</translation>
    </message>
    <message>
        <source>Configure &amp;network proxy...</source>
        <translation>Configurar el proxy de la &amp;red...</translation>
    </message>
    <message>
        <source>Logged out as %1</source>
        <translation>Se ha cerrado la sesión como %1</translation>
    </message>
    <message>
        <source>Sync failed</source>
        <translation>La sincronización falló</translation>
    </message>
    <message>
        <source>The last sync of account %1 has failed with error: %2</source>
        <translation>La última sincronización de la cuenta %1 ha fallado con el error: %2</translation>
    </message>
    <message>
        <source>The last sync has failed with error: %1</source>
        <translation>La última sincronización ha fallado con el error: %1</translation>
    </message>
    <message>
        <source>Clicking &apos;Retry&apos; will attempt to resume synchronisation;
Clicking &apos;Cancel&apos; will stop further synchronisation of this account until logout or Quaternion restart.</source>
        <translation>Al hacer clic en &apos;Reintentar&apos; se intentará reanudar la sincronización;
Al hacer clic en &quot;Cancelar&quot; se detendrá la sincronización de esta cuenta hasta que se cierre la sesión o se reinicie Quaternion.</translation>
    </message>
    <message>
        <source>Before this server can process your information, you have to agree with its terms and conditions; please click the button below to open the web page where you can do that</source>
        <translation>Antes de que este servidor pueda procesar su información, usted tiene que estar de acuerdo con sus términos y condiciones; por favor haga clic en el botón de abajo para abrir la página web donde puede hacer eso</translation>
    </message>
    <message>
        <source>Open web page</source>
        <translation>Abrir página web</translation>
    </message>
    <message>
        <source>About Quaternion</source>
        <translation>Acerca de Quaternion</translation>
    </message>
    <message>
        <source>Welcome to Quaternion</source>
        <translation>Bienvenido a Quaternion</translation>
    </message>
    <message>
        <source>Joined %1 as %2</source>
        <translation>Se unió a %1 como %2</translation>
    </message>
    <message>
        <source>Couldn&apos;t connect to the server as %1; will retry within %2 seconds</source>
        <translation>No se pudo conectar al servidor como %1; volverá a intentarlo en %2 segundos</translation>
    </message>
    <message>
        <source>Reconnecting...</source>
        <translation>Reconectando...</translation>
    </message>
    <message>
        <source>No SSL support</source>
        <translation>Sin soporte SSL</translation>
    </message>
    <message>
        <source>Your SSL configuration does not allow Quaternion to establish secure connections.</source>
        <translation>Su configuración SSL no permite que Quaternion establezca conexiones seguras.</translation>
    </message>
    <message>
        <source>SSL error</source>
        <translation>Error SSL</translation>
    </message>
    <message>
        <source>Proxy needs authentication</source>
        <translation>El proxy necesita autenticación</translation>
    </message>
    <message>
        <source>Authenticate</source>
        <translation>Autenticar</translation>
    </message>
    <message>
        <source>User name</source>
        <translation>Nombre de usuario</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Contraseña</translation>
    </message>
    <message>
        <source>&amp;Thanks</source>
        <translation>&amp;Gracias</translation>
    </message>
    <message>
        <source>Original project author: %1</source>
        <translation>Autor del proyecto original: %1</translation>
    </message>
    <message>
        <source>Web page</source>
        <translation>Página web</translation>
    </message>
    <message>
        <source>Project leader: %1</source>
        <translation>Líder del proyecto: %1</translation>
    </message>
    <message>
        <source>Contributors:</source>
        <translation>Colaboradores:</translation>
    </message>
    <message>
        <source>Quaternion contributors @ GitHub</source>
        <translation>Colaboradores de Quaternion @ GitHub</translation>
    </message>
    <message>
        <source>Quaternion translators @ Lokalise.co</source>
        <translation>Traductores de Quaternion Lokalise.co</translation>
    </message>
    <message>
        <source>Made with:</source>
        <translation>Hecho con:</translation>
    </message>
    <message>
        <source>Show join and leave events</source>
        <translation>Mostrar eventos de unirse y dejar</translation>
    </message>
    <message>
        <source>Use shuttle scrollbar (requires restart)</source>
        <translation>Use la barra de desplazamiento de la lanzaderar (requiere reinicio)</translation>
    </message>
    <message>
        <source>Control scroll velocity instead of position with the timeline scrollbar</source>
        <translation>Controle la velocidad de desplazamiento en lugar de la posición con la barra de desplazamiento de la línea de tiempo</translation>
    </message>
    <message>
        <source>Request URL: %1
Response:
%2</source>
        <translation>URL de solicitud: %1 
 Respuesta: 
 %2</translation>
    </message>
    <message>
        <source>Close to tray</source>
        <translation>Cerrar a la bandeja</translation>
    </message>
    <message>
        <source>Make close button [X] minimize to tray instead of closing main window</source>
        <translation>Hacer que el botón de cierre [X] minimice a la bandeja en lugar de cerrar la ventana principal</translation>
    </message>
    <message>
        <source>Show/hide meaningless activity (join-leave pairs and redacted events between)</source>
        <translation>Mostrar/ocultar actividades sin sentido (unir-dejar pares y eventos redactados entre ellos)</translation>
    </message>
    <message>
        <source>Built from Git, commit SHA:</source>
        <translation>Construido desde Git, confirme SHA:</translation>
    </message>
    <message>
        <source>Library commit SHA:</source>
        <translation>SHA de confirmación de biblioteca:</translation>
    </message>
    <message>
        <source>Open room...</source>
        <translation>Sala abierta...</translation>
    </message>
    <message>
        <source>Open room</source>
        <translation>Sala abierta</translation>
    </message>
    <message>
        <source>Open a room from the room list</source>
        <translation>Abrir una sala de la lista de salas</translation>
    </message>
    <message>
        <source>Couldn&apos;t delete access token</source>
        <translation>No se pudo eliminar el token de acceso</translation>
    </message>
    <message>
        <source>Open direct chat?</source>
        <translation>¿Abrir chat directo?</translation>
    </message>
    <message>
        <source>Open direct chat with user %1?</source>
        <translation>¿Abrir chat directo con el usuario %1?</translation>
    </message>
    <message>
        <source>Room not found</source>
        <translation>Sala no encontrada</translation>
    </message>
    <message>
        <source>There&apos;s no room %1 in the room list. Check the spelling and the account.</source>
        <translation>No hay %1 en la lista de salas. Compruebe la ortografía y la cuenta.</translation>
    </message>
    <message>
        <source>Confirm your account to open %1</source>
        <translation>Confirme su cuenta para abrir %1</translation>
    </message>
    <message>
        <source>Confirm account</source>
        <translation>Confirmar la cuenta</translation>
    </message>
    <message>
        <source>Account</source>
        <translation>Cuenta</translation>
    </message>
    <message>
        <source>Room ID (starting with !)
or alias (starting with #)</source>
        <translation>ID de la sala (comenzando con !)
o alias (comenzando con #)</translation>
    </message>
    <message>
        <source>Confirm account to join %1</source>
        <translation>Confirme la cuenta para unirse a %1</translation>
    </message>
    <message>
        <source>Edit quote style</source>
        <translation>Editar el estilo de la comilla</translation>
    </message>
    <message>
        <source>Markdown (prepend each line with &gt;)</source>
        <translation>Markdown (anteponer cada línea con &gt;)</translation>
    </message>
    <message>
        <source>Custom (apply regex from the config file)</source>
        <translation>Personalizado (aplique expresiones regulares desde el archivo de configuración)</translation>
    </message>
    <message>
        <source>Locale&apos;s default (%1)</source>
        <translation>Configuración regional predeterminada (%1)</translation>
    </message>
    <message>
        <source>Example quote</source>
        <translation>Ejemplo de comillas</translation>
    </message>
    <message>
        <source>Choose the default style of quotes</source>
        <translation>Elija el estilo predeterminado de comillas</translation>
    </message>
    <message>
        <source>Special thanks to %1 for all the testing effort</source>
        <translation>Un agradecimiento especial a %1 por todo el esfuerzo de prueba</translation>
    </message>
    <message>
        <source>libQuotient contributors @ GitHub</source>
        <translation>Colaboradores de libQuotient en @ GitHub</translation>
    </message>
    <message>
        <source>First sync completed for %1</source>
        <translation>Primera sincronización completada para %1</translation>
    </message>
    <message>
        <source>Quaternion couldn&apos;t delete the access token from the keychain.</source>
        <translation>Quaternion no pudo eliminar el token de acceso del llavero.</translation>
    </message>
    <message>
        <source>Please connect to a server</source>
        <translation>Por favor, conéctese a un servidor</translation>
    </message>
    <message>
        <source>Confirm your account to open a direct chat with %1</source>
        <translation>Confirme su cuenta para abrir un chat directo con %1</translation>
    </message>
    <message>
        <source>Log&amp;out</source>
        <translation>&amp;Cerrar sesión</translation>
    </message>
    <message>
        <source>Tags can be wildcarded by * next to dot(s)
Clear the box to reset to defaults
Special tags starting with &quot;im.quotient.&quot; are: %1
User-defined tags should start with &quot;u.&quot;</source>
        <translation>Las etiquetas pueden ser marcadas con un * (comodín) al lado de un punto[s].
Desactive la casilla para restablecer los valores predeterminados.
Etiquetas especiales que comienzan con &quot;im.quotient.&quot; son: %1
Las etiquetas definidas por el usuario deben comenzar con &quot;u.&quot;</translation>
    </message>
    <message>
        <source>Room or user ID, room alias,
Matrix URI or matrix.to link</source>
        <translation>ID de sala o del usuario, alias de sala, 
Matrix URI o enlace matriz.to</translation>
    </message>
    <message>
        <source>Join room</source>
        <translation>Unirse a la sala</translation>
    </message>
    <message>
        <source>Quaternion project contributors</source>
        <translation>Colaboradores del proyecto Quaternion</translation>
    </message>
    <message>
        <source>Felix Rohrbach</source>
        <translation>Felix Rohrbach</translation>
    </message>
    <message>
        <source>Alexey &quot;Kitsune&quot; Rusakov</source>
        <translation>Alexey &quot;Kitsune&quot; Rusakov</translation>
    </message>
</context>
<context>
    <name>MessageEventModel</name>
    <message>
        <source>Today</source>
        <translation>Hoy</translation>
    </message>
    <message>
        <source>Yesterday</source>
        <translation>Ayer</translation>
    </message>
    <message>
        <source>The day before yesterday</source>
        <translation>Anteayer</translation>
    </message>
    <message>
        <source>Redacted</source>
        <translation>Redactado</translation>
    </message>
    <message>
        <source>Redacted: %1</source>
        <translation>Redactado: %1</translation>
    </message>
    <message>
        <source>a file</source>
        <translation>un archivo</translation>
    </message>
    <message>
        <source>invited %1 to the room</source>
        <translation>invitado %1 a la sala</translation>
    </message>
    <message>
        <source>joined the room</source>
        <translation>se unió a la sala</translation>
    </message>
    <message>
        <source>cleared the display name</source>
        <translation>limpiado el nombre de visualización</translation>
    </message>
    <message>
        <source>changed the display name to %1</source>
        <translation>cambiado el nombre para mostrar a %1</translation>
    </message>
    <message>
        <source>cleared the avatar</source>
        <translation>limpiado el avatar</translation>
    </message>
    <message>
        <source>updated the avatar</source>
        <translation>actualizado el avatar</translation>
    </message>
    <message>
        <source>unbanned %1</source>
        <translation>sin suspender %1</translation>
    </message>
    <message>
        <source>self-unbanned</source>
        <translation>sin prohibiciones</translation>
    </message>
    <message>
        <source>left the room</source>
        <translation>salió de la sala</translation>
    </message>
    <message>
        <source>self-banned from the room</source>
        <translation>auto-suspendido de la sala</translation>
    </message>
    <message>
        <source>knocked</source>
        <translation>Golpeó</translation>
    </message>
    <message>
        <source>made something unknown</source>
        <translation>hizo algo desconocido</translation>
    </message>
    <message>
        <source>cleared the room main alias</source>
        <translation>limpiado el alias principal de la sala</translation>
    </message>
    <message>
        <source>set the room main alias to: %1</source>
        <translation>establecer el alias principal de la sala en: %1</translation>
    </message>
    <message>
        <source>cleared the room name</source>
        <translation>limpiado el nombre de la sala</translation>
    </message>
    <message>
        <source>set the room name to: %1</source>
        <translation>establecer el nombre de la sala en: %1</translation>
    </message>
    <message>
        <source>cleared the topic</source>
        <translation>limpiado el tema</translation>
    </message>
    <message>
        <source>set the topic to: %1</source>
        <translation>establecer el tema en: %1</translation>
    </message>
    <message>
        <source>changed the room avatar</source>
        <translation>cambió el avatar de la sala</translation>
    </message>
    <message>
        <source>activated End-to-End Encryption</source>
        <translation>activado Cifrado de Extremo a Extremo</translation>
    </message>
    <message>
        <source>withdrew %1&apos;s invitation</source>
        <translation>retiró la invitación de %1</translation>
    </message>
    <message>
        <source>rejected the invitation</source>
        <translation>rechazó la invitación</translation>
    </message>
    <message>
        <source>updated the database</source>
        <translation>actualizada la base de datos</translation>
    </message>
    <message>
        <source>updated %1 state</source>
        <translation>Estado actualizado de %1</translation>
    </message>
    <message>
        <source>updated %1 state for %2</source>
        <translation>estado actualizado de %1 para %2</translation>
    </message>
    <message>
        <source>Unknown event</source>
        <translation>Evento desconocido</translation>
    </message>
    <message>
        <source>upgraded the room to version %1</source>
        <translation>actualizada la sala a la versión %1</translation>
    </message>
    <message>
        <source>created the room, version %1</source>
        <translation>creada la sala, versión %1</translation>
    </message>
    <message>
        <source>banned %1 from the room: %2</source>
        <translation>suspendido %1 de la sala: %2</translation>
    </message>
    <message>
        <source>kicked %1 from the room: %2</source>
        <translation>ha sacado a %1 de la sala: %2</translation>
    </message>
    <message>
        <source> and </source>
        <translation> y </translation>
    </message>
    <message>
        <source>(repeated)</source>
        <translation>(repetido)</translation>
    </message>
    <message>
        <source>kicked %1 from the room</source>
        <translation>ha sacado a %1 de la sala</translation>
    </message>
</context>
<context>
    <name>NetworkConfigDialog</name>
    <message>
        <source>Network proxy settings</source>
        <translation>Configuración de proxy de red</translation>
    </message>
    <message>
        <source>&amp;Override system defaults</source>
        <translation>&amp;Reemplazar los valores predeterminados del sistema</translation>
    </message>
    <message>
        <source>&amp;No proxy</source>
        <translation>&amp;Sin proxy</translation>
    </message>
    <message>
        <source>&amp;HTTP(S) proxy</source>
        <translation>&amp;Proxy HTTP(S)</translation>
    </message>
    <message>
        <source>&amp;SOCKS5 proxy</source>
        <translation>Proxy &amp;SOCKS5</translation>
    </message>
    <message>
        <source>Host</source>
        <translation>Anfitrión</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Puerto</translation>
    </message>
    <message>
        <source>User name</source>
        <translation>Nombre de usuario</translation>
    </message>
</context>
<context>
    <name>RoomDialogBase</name>
    <message>
        <source>Publish room in room directory</source>
        <translation>Publicar sala en el directorio de salas</translation>
    </message>
    <message>
        <source>Allow guest accounts to join the room</source>
        <translation>Permitir que las cuentas de invitados se unan a la sala</translation>
    </message>
    <message>
        <source>Account</source>
        <translation>Cuenta</translation>
    </message>
    <message>
        <source>Room name</source>
        <translation>Nombre de la sala</translation>
    </message>
    <message>
        <source>Primary alias</source>
        <translation>Alias principal</translation>
    </message>
    <message>
        <source>Topic</source>
        <translation>Tema</translation>
    </message>
    <message>
        <source>About room versions</source>
        <translation>Acerca de las versiones de sala</translation>
    </message>
    <message>
        <source>(loading)</source>
        <translation>(cargando)</translation>
    </message>
    <message>
        <source>default</source>
        <translation>Predeterminado</translation>
    </message>
    <message>
        <source>stable</source>
        <translation>estable</translation>
    </message>
    <message>
        <source>Room version</source>
        <translation>Versión de la sala</translation>
    </message>
    <message>
        <source>Continue with unstable version?</source>
        <translation>¿Continuar con la versión inestable?</translation>
    </message>
    <message>
        <source>You are using an UNSTABLE room version (%1). The server may stop supporting it at any moment. Do you still want to use this version?</source>
        <translation>Está utilizando una versión de sala INESTABLE (%1). El servidor puede dejar de soportarlo en cualquier momento. ¿Aún desea utilizar esta versión?</translation>
    </message>
</context>
<context>
    <name>RoomListDock</name>
    <message>
        <source>Mark room as read</source>
        <translation>Marcar sala como leída</translation>
    </message>
    <message>
        <source>Add tags...</source>
        <translation>Agregar etiquetas...</translation>
    </message>
    <message>
        <source>Join room</source>
        <translation>Unirse a la sala</translation>
    </message>
    <message>
        <source>Forget room</source>
        <translation>Olvidar sala</translation>
    </message>
    <message>
        <source>Remove tag</source>
        <translation>Remover etiqueta</translation>
    </message>
    <message>
        <source>Reject invitation</source>
        <translation>Rechazar invitación</translation>
    </message>
    <message>
        <source>Leave room</source>
        <translation>Dejar la sala</translation>
    </message>
    <message>
        <source>Enter new tags for the room</source>
        <translation>Ingrese nuevas etiquetas para la sala</translation>
    </message>
    <message>
        <source>Enter tags to add to this room, one tag per line</source>
        <translation>Ingrese etiquetas para agregar a esta sala, una etiqueta por línea</translation>
    </message>
    <message>
        <source>Change room &amp;settings...</source>
        <translation>Cambiar sala y configuraciones ...</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Añadir</translation>
    </message>
    <message>
        <source>Rooms (%L1)</source>
        <translation>Salas (%L1)</translation>
    </message>
</context>
<context>
    <name>RoomListModel</name>
    <message>
        <source>Invited</source>
        <translation>Invitado</translation>
    </message>
    <message>
        <source>Low priority</source>
        <translation>Baja prioridad</translation>
    </message>
    <message>
        <source>People</source>
        <translation>Personas</translation>
    </message>
    <message>
        <source>Ungrouped rooms</source>
        <translation>Salas desagrupadas</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Izquierda</translation>
    </message>
    <message numerus="yes">
        <source>%1 (%Ln room(s))</source>
        <translation>
            <numerusform>%1 (%Ln sala)</numerusform>
            <numerusform>%1 (%Ln salas)</numerusform>
        </translation>
    </message>
    <message>
        <source>%1 (as %2)</source>
        <translation>%1 (como %2)</translation>
    </message>
    <message>
        <source>Main alias: %1</source>
        <translation>Alias principal: %1</translation>
    </message>
    <message>
        <source>Direct chat with %1</source>
        <translation>Charla directa con %1</translation>
    </message>
    <message>
        <source>The room enforces encryption</source>
        <translation>La sala impone el cifrado</translation>
    </message>
    <message>
        <source>Favourites</source>
        <translation>Favoritos</translation>
    </message>
    <message>
        <source>This room&apos;s version is unstable!</source>
        <translation>¡La versión de esta sala es inestable!</translation>
    </message>
    <message>
        <source>Consider upgrading to a stable version (use room settings for that)</source>
        <translation>Considere actualizar a una versión estable (use la configuración de sala para ello)</translation>
    </message>
    <message>
        <source>Joined: %L1</source>
        <translation>Unidos: %L1</translation>
    </message>
    <message>
        <source>Invited: %L1</source>
        <translation>Invitado: %L1</translation>
    </message>
</context>
<context>
    <name>RoomSettingsDialog</name>
    <message>
        <source>Room settings: %1</source>
        <translation>Configuración de sala: %1</translation>
    </message>
    <message>
        <source>Update room</source>
        <translation>Actualización de la sala</translation>
    </message>
    <message>
        <source>Tags</source>
        <translation>Etiquetas</translation>
    </message>
    <message>
        <source>This version is unstable! Consider upgrading.</source>
        <translation>Esta versión es inestable! Considere la posibilidad de actualizar.</translation>
    </message>
    <message>
        <source>Upgrade</source>
        <translation>Actualización</translation>
    </message>
    <message>
        <source>Choose new room version</source>
        <translation>Elija la nueva versión de sala</translation>
    </message>
    <message>
        <source>You are about to upgrade %1.
This operation cannot be reverted.</source>
        <translation>Está a punto de actualizar %1. 
Esta operación no se puede revertir.</translation>
    </message>
    <message>
        <source>Creating the new room version, please wait</source>
        <translation>Creando la nueva versión de la sala, por favor espere</translation>
    </message>
    <message>
        <source>Room identifier</source>
        <translation>Identificador de sala</translation>
    </message>
</context>
<context>
    <name>UserListDock</name>
    <message>
        <source>Users</source>
        <translation>Usuarios</translation>
    </message>
    <message>
        <source>Open direct chat</source>
        <translation>Abrir chat directo</translation>
    </message>
    <message>
        <source>Mention user</source>
        <translation>Mencionar usuario</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Búsqueda</translation>
    </message>
    <message>
        <source>Ignore user</source>
        <translation>Ignorar usuario</translation>
    </message>
    <message>
        <source>Kick user</source>
        <translation>Remover usuario</translation>
    </message>
    <message>
        <source>Ban user</source>
        <translation>Prohibir usuario</translation>
    </message>
    <message>
        <source>Kick %1</source>
        <translation>Remover %1</translation>
    </message>
    <message>
        <source>Reason</source>
        <translation>Razón</translation>
    </message>
    <message>
        <source>Ban %1</source>
        <translation>Prohibir %1</translation>
    </message>
    <message>
        <source>(%L1 out of %L2)</source>
        <translation>(%L1 de %L2)</translation>
    </message>
</context>
<context>
    <name>FileContent</name>
    <message>
        <source>Size: %1, declared type: %2</source>
        <translation>Tamaño: %1, tipo declarado: %2</translation>
    </message>
    <message>
        <source>Open after downloading</source>
        <translation>Abrir después de la descarga</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Save as...</source>
        <translation>Guardar como...</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Abrir</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Abrir carpeta</translation>
    </message>
    <message>
        <source>uploaded from %1</source>
        <translation>subido desde %1</translation>
    </message>
    <message>
        <source>being uploaded from %1</source>
        <translation>siendo subido desde %1</translation>
    </message>
    <message>
        <source>downloaded to %1</source>
        <translation>descargado a %1</translation>
    </message>
</context>
<context>
    <name>TimelineItem</name>
    <message>
        <source>Resend</source>
        <translation>Reenviar</translation>
    </message>
    <message>
        <source>Discard</source>
        <translation>Descartar</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <source>Quaternion - an IM client for the Matrix protocol</source>
        <translation>Quaternion: un cliente de mensajería instantánea para el protocolo Matrix</translation>
    </message>
    <message>
        <source>Override locale</source>
        <translation>Reemplazar la configuración regional</translation>
    </message>
    <message>
        <source>locale</source>
        <translation>configuración regional</translation>
    </message>
    <message>
        <source>Hide main window on startup</source>
        <translation>Ocultar la ventana principal al iniciar</translation>
    </message>
</context>
<context>
    <name>SystemTrayIcon</name>
    <message>
        <source>Highlight in %1</source>
        <translation>Resaltar en %1</translation>
    </message>
    <message numerus="yes">
        <source>%Ln highlight(s)</source>
        <translation>
            <numerusform>%Ln destacado</numerusform>
            <numerusform>%Ln destacados</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>ThumbnailResponse</name>
    <message>
        <source>Image request has been cancelled</source>
        <translation>La solicitud de imagen ha sido cancelada</translation>
    </message>
</context>
<context>
    <name>ProfileDialog</name>
    <message>
        <source>Account</source>
        <translation>Cuenta</translation>
    </message>
    <message>
        <source>Access token</source>
        <translation>Token de acceso</translation>
    </message>
</context>
<context>
    <name>TimelineWidget</name>
    <message>
        <source>Save file as</source>
        <translation>Guardar archivo como</translation>
    </message>
    <message>
        <source>Redact</source>
        <translation>Redactar</translation>
    </message>
    <message>
        <source>Quote</source>
        <translation>Comillas</translation>
    </message>
    <message>
        <source>Open externally</source>
        <translation>Abrir externamente</translation>
    </message>
</context>
</TS>
